@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 our $VERSION = 0.01;
 
-use Catalyst qw[-Engine=Test HashedCookies];
+use Catalyst qw[HashedCookies];
 use File::Spec::Functions qw[catpath splitpath rel2abs];
 
 __PACKAGE__->config(
